=================================
Seed Identity Store documentation
=================================

The Seed Identity Store is one of the microservices in the Seed Stack.

The Identity Store has two key responsibilities:

- Store the unique Identity of any end-user created in the Seed system.
- Store the Opt-out or Opt-in status for any end-user in the Seed system.

Getting started
===============

The following resources are provided to help you get started running or
developing the Seed Identity Store:

* Learn about the :doc:`Requirements <requirements>` for running the service
  and basic :doc:`Setup <setup>` instructions.
* Read about the :doc:`Data Models <models>` used by the service.
* Read about the :doc:`Authorization <auth>` requirements.
* Browse the :doc:`API Documentation <apis>` for the available endpoints and
  parameters.
* Learn about what is required when running the service in
  :doc:`Production <production>`
